@@ -38,7 +38,8 @@ def delete_vlan_binding(context, record_dict):
     """Delete vlan bindings of a given physical port."""
     session = context.session
     with session.begin(subtransactions=True):
-        if(record_dict['vlan'] and record_dict['logical_switch_uuid']):
+        if (record_dict['vlan'] is not None and
+                record_dict['logical_switch_uuid']):
             session.query(models.VlanBindings).filter_by(
                 port_uuid=record_dict['port_uuid'], vlan=record_dict['vlan'],
                 logical_switch_uuid=record_dict['logical_switch_uuid'],
@@ -283,7 +284,7 @@ def get_ucast_mac_local(context, record_dict):
 
 
 def get_ucast_mac_remote_by_mac_and_ls(context, record_dict):
-    """Get ucast macs remote that matches the MAC addres and
+    """Get ucast macs remote that matches the MAC address and
 
        ovsdb_identifier.
     """
@@ -461,8 +462,8 @@ def delete_pending_ucast_mac_remote(context, operation,
     """Delete a pending ucast_mac_remote."""
     session = context.session
     with session.begin(subtransactions=True):
-        if(mac_remote and logical_switch_id
-           and ovsdb_identifier and operation):
+        if(mac_remote and logical_switch_id and
+           ovsdb_identifier and operation):
             query = session.query(models.PendingUcastMacsRemote).filter_by(
                 mac=mac_remote,
                 ovsdb_identifier=ovsdb_identifier,
@@ -505,3 +506,66 @@ def get_all_ucast_mac_remote_by_ls(context, record_dict):
         return session.query(models.UcastMacsRemotes).filter_by(
             ovsdb_identifier=record_dict['ovsdb_identifier'],
             logical_switch_id=record_dict['logical_switch_id']).all()
+
+
+def delete_all_physical_locators_by_ovsdb_identifier(context,
+                                                     ovsdb_identifier):
+    """Delete all physical locators based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.PhysicalLocators).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
+
+
+def delete_all_physical_switches_by_ovsdb_identifier(context,
+                                                     ovsdb_identifier):
+    """Delete all physical switches based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.PhysicalSwitches).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
+
+
+def delete_all_physical_ports_by_ovsdb_identifier(context,
+                                                  ovsdb_identifier):
+    """Delete all physical ports based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.PhysicalPorts).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
+
+
+def delete_all_logical_switches_by_ovsdb_identifier(context,
+                                                    ovsdb_identifier):
+    """Delete all physical switches based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.LogicalSwitches).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
+
+
+def delete_all_ucast_macs_locals_by_ovsdb_identifier(context,
+                                                     ovsdb_identifier):
+    """Delete all ucast mac locals based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.UcastMacsLocals).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
+
+
+def delete_all_ucast_macs_remotes_by_ovsdb_identifier(context,
+                                                      ovsdb_identifier):
+    """Delete all ucast mac remotes based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.UcastMacsRemotes).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
+
+
+def delete_all_vlan_bindings_by_ovsdb_identifier(context,
+                                                 ovsdb_identifier):
+    """Delete all vlan bindings based on ovsdb identifier."""
+    session = context.session
+    with session.begin(subtransactions=True):
+        session.query(models.VlanBindings).filter_by(
+            ovsdb_identifier=ovsdb_identifier).delete()
