@@ -17,8 +17,8 @@ from oslo_db import exception as d_exc
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
-from neutron import context
 from neutron.tests.unit import testlib_api
+from neutron_lib import context
 
 from networking_l2gw.db.l2gateway.ovsdb import lib
 from networking_l2gw.db.l2gateway.ovsdb import models
@@ -341,6 +341,15 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
                        'ovsdb_identifier': 'host1'}
         return record_dict
 
+    def _get_vlan0_binding_dict(self):
+        port_uuid = _uuid()
+        ls_uuid = _uuid()
+        record_dict = {'port_uuid': port_uuid,
+                       'vlan': 0,
+                       'logical_switch_uuid': ls_uuid,
+                       'ovsdb_identifier': 'host1'}
+        return record_dict
+
     def _create_vlan_binding(self, record_dict, port_uuid=None):
         if port_uuid:
             record_dict['port_uuid'] = port_uuid
@@ -382,6 +391,13 @@ class OvsdbLibTestCase(testlib_api.SqlTestCase):
         count = self.ctx.session.query(models.VlanBindings).count()
         self.assertEqual(count, 0)
 
+    def test_delete_vlan0_binding(self):
+        record_dict = self._get_vlan0_binding_dict()
+        self._create_vlan_binding(record_dict)
+        lib.delete_vlan_binding(self.ctx, record_dict)
+        count = self.ctx.session.query(models.VlanBindings).count()
+        self.assertEqual(count, 0)
+
     def test_get_logical_switch_by_name(self):
         record_dict = self._get_logical_switch_dict()
         with self.ctx.session.begin(subtransactions=True):
